﻿/*
 * P4.Net *
Copyright (c) 2007 Shawn Hladky

Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
and associated documentation files (the "Software"), to deal in the Software without 
restriction, including without limitation the rights to use, copy, modify, merge, publish, 
distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the 
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or 
substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 */
using System;
using System.Text;
using System.IO;

namespace P4API
{
    /// <summary>
    /// 
    /// </summary>
    public abstract class P4Callback
    {
        private Encoding _encoding = null;
        internal void SetEncoding(Encoding encoding)
        {
            _encoding = (Encoding)encoding.Clone();
        }

        private string _specDef = null;
        internal void SetSpecDef(string specDef)
        {
            _specDef = specDef;
        }
        /// <summary>
        /// Gets the spec def.
        /// </summary>
        /// <value>The spec def.</value>
        protected string SpecDef
        {
            get
            {
                return _specDef;
            }
        }

        /// <summary>
        /// Gets the content encoding.
        /// </summary>
        /// <value>The content encoding.</value>
        protected Encoding ContentEncoding
        {
            get
            {
                return _encoding;
            }
        }

        ///// <summary>
        ///// Diffs the specified f1.
        ///// </summary>
        ///// <param name="f1">The f1.</param>
        ///// <param name="f2">The f2.</param>
        ///// <param name="diffFlags">The diff flags.</param>
        //public virtual void Diff(FileInfo f1, FileInfo f2, string diffFlags)
        //{
            
        //}

        /// <summary>
        /// Edits the specified f1.
        /// </summary>
        /// <param name="f1">The f1.</param>
        public virtual void Edit(FileInfo f1)
        {
        }
        /// <summary>
        /// Prompts the specified MSG.
        /// </summary>
        /// <param name="msg">The MSG.</param>
        /// <param name="rsp">The RSP.</param>
        public virtual void Prompt(string msg, ref string rsp)
        {
        }

        /// <summary>
        /// Finisheds this instance.
        /// </summary>
        public virtual void Finished()
        {
            // do nothing
        }
        /// <summary>
        /// Cancels this instance.
        /// </summary>
        /// <returns></returns>
        public virtual bool Cancel()
        {
            return false;
        }

        /// <summary>
        /// Outputs the content.
        /// </summary>
        /// <param name="buffer">The buffer.</param>
        /// <param name="IsText">if set to <c>true</c> [is text].</param>
        public virtual void OutputContent(byte[] buffer, bool IsText)
        {
        }
        /// <summary>
        /// Inputs the data.
        /// </summary>
        /// <param name="buffer">The buffer.</param>
        public virtual void InputData(StringBuilder buffer)
        {
        }
        /// <summary>
        /// Outputs the record.
        /// </summary>
        /// <param name="record">The record.</param>
        public virtual void OutputRecord(P4Record record)
        {
        }
        /// <summary>
        /// Outputs the message.
        /// </summary>
        /// <param name="message">The message.</param>
        public abstract void OutputMessage(P4Message message);

        /// <summary>
        /// Outputs the info.
        /// </summary>
        /// <param name="data">The data.</param>
        public virtual void OutputInfo(string data)
        {
        }
        /// <summary>
        /// Resolves the file.
        /// </summary>
        /// <param name="mergeData">The merge data.</param>
        /// <returns></returns>
        public virtual MergeAction ResolveFile(MergeData mergeData)
        {
            return MergeAction.Quit;
        }
    }
}
